Module protocol

Module protocol 

Structs

CommandRequest
POST /api/sessions/{id}/command - request body.
CommandResponse
POST /api/sessions/{id}/command - response body.
CommandResult
Result of a command execution.
ConsoleEvent
Console event captured from the browser.
HandshakeRequest
POST /api/handshake - request body.
HandshakeResponse
POST /api/handshake - response body.
NetworkEvent
Network event captured from the browser.
ScreenshotData
Screenshot-specific result data.
SessionInfo
GET /api/sessions - single session info.

Enums

BrowserCommand
Commands that can be sent to a browser session.
BrowserMessage
Messages sent from browser runtime to daemon via WebSocket.
ConsoleLevel
DaemonMessage
Messages sent from daemon to browser runtime via WebSocket.
ScreenshotHook
Pre-screenshot hooks to prepare the page.
SocketState